import argparse
import os

import numpy as np
import pydicom

from mu_map.file.dicom import update_dcm, change_uid
from mu_map.file.interfile import load_interfile_img

parser = argparse.ArgumentParser(
    description="convert an Interfile image to a DICOM image",
    formatter_class=argparse.ArgumentDefaultsHelpFormatter,
)
parser.add_argument(
    "--inter", type=str, required=True, help="the Interfile image to be converted"
)
parser.add_argument(
    "--dcm",
    type=str,
    required=True,
    help="a DICOM reference image - data and according fields are exchanged from the Interfile image",
)
parser.add_argument(
    "--out",
    type=str,
    help="the output file - defaults to the Interfile input with a dcm extension",
)
parser.add_argument(
    "--description",
    type=str,
    help="if provided the series description will be updated",
)
args = parser.parse_args()

if args.out is None:
    args.out = os.path.splitext(args.inter)[0] + ".dcm"

image = load_interfile_img(args.inter)

dcm = pydicom.dcmread(args.dcm)
dcm = update_dcm(dcm.copy(), image)
dcm = change_uid(dcm)
if args.description:
    dcm.SeriesDescription = args.description
pydicom.dcmwrite(args.out, dcm)
